@@ -12,71 +12,43 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import posixpath
-
-from oslo_config import cfg
 from oslo_log import log as oslo_logging
 from six.moves.urllib import error
-from six.moves.urllib import request
 
+from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit.metadata.services import base
-from cloudbaseinit.metadata.services import baseopenstackservice
+from cloudbaseinit.metadata.services import baseopenstackservice as baseos
 from cloudbaseinit.utils import network
 
-opts = [
-    cfg.StrOpt('metadata_base_url', default='http://169.254.169.254/',
-               help='The base URL where the service looks for metadata'),
-    cfg.BoolOpt('add_metadata_private_ip_route', default=True,
-                help='Add a route for the metadata ip address to the gateway'),
-]
-
-CONF = cfg.CONF
-CONF.register_opts(opts)
-
+CONF = cloudbaseinit_conf.CONF
 LOG = oslo_logging.getLogger(__name__)
 
 
-class HttpService(baseopenstackservice.BaseOpenStackService):
+class HttpService(base.BaseHTTPMetadataService, baseos.BaseOpenStackService):
     _POST_PASSWORD_MD_VER = '2013-04-04'
 
     def __init__(self):
-        super(HttpService, self).__init__()
+        super(HttpService, self).__init__(
+            base_url=CONF.openstack.metadata_base_url,
+            https_allow_insecure=CONF.openstack.https_allow_insecure,
+            https_ca_bundle=CONF.openstack.https_ca_bundle)
         self._enable_retry = True
 
     def load(self):
         super(HttpService, self).load()
-        if CONF.add_metadata_private_ip_route:
-            network.check_metadata_ip_route(CONF.metadata_base_url)
+        if CONF.openstack.add_metadata_private_ip_route:
+            network.check_metadata_ip_route(CONF.openstack.metadata_base_url)
 
         try:
             self._get_meta_data()
             return True
         except Exception:
             LOG.debug('Metadata not found at URL \'%s\'' %
-                      CONF.metadata_base_url)
+                      CONF.openstack.metadata_base_url)
             return False
 
-    def _get_response(self, req):
-        try:
-            return request.urlopen(req)
-        except error.HTTPError as ex:
-            if ex.code == 404:
-                raise base.NotExistingMetadataException()
-            else:
-                raise
-
-    def _get_data(self, path):
-        norm_path = posixpath.join(CONF.metadata_base_url, path)
-        LOG.debug('Getting metadata from: %s', norm_path)
-        req = request.Request(norm_path)
-        response = self._get_response(req)
-        return response.read()
-
     def _post_data(self, path, data):
-        norm_path = posixpath.join(CONF.metadata_base_url, path)
-        LOG.debug('Posting metadata to: %s', norm_path)
-        req = request.Request(norm_path, data=data)
-        self._get_response(req)
+        self._http_request(path, data=data)
         return True
 
     def _get_password_path(self):
