@@ -29,7 +29,7 @@ class PartHandlerPlugin(base.BaseUserDataPlugin):
     def process(self, part):
         temp_dir = tempfile.gettempdir()
         part_handler_path = os.path.join(temp_dir, part.get_filename())
-        encoding.write_file(part_handler_path, part.get_payload())
+        encoding.write_file(part_handler_path, part.get_payload(decode=True))
 
         part_handler = classloader.ClassLoader().load_module(part_handler_path)
 
