@@ -17,6 +17,8 @@ import unittest
 
 import ddt
 
+from cloudbaseinit.utils import serialization
+
 try:
     import unittest.mock as mock
 except ImportError:
@@ -24,12 +26,83 @@ except ImportError:
 
 from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit import exception
+from cloudbaseinit.models import network as network_model
 from cloudbaseinit.tests import testutils
 
 
 CONF = cloudbaseinit_conf.CONF
 BASE_MODULE_PATH = 'cloudbaseinit.metadata.services.vmwareguestinfoservice'
 MODULE_PATH = BASE_MODULE_PATH + '.VMwareGuestInfoService'
+NETWORK_CONFIG_TEST_DATA_V1 = """
+network:
+  version: 1
+  config:
+  - type: physical
+    name: eth0
+    mac_address: "00:50:56:a1:8e:43"
+    subnets:
+    - type: static
+      address: 172.26.0.37
+      netmask: 255.255.255.240
+      gateway: 172.26.0.33
+      dns_nameservers:
+      - 10.20.145.1
+      - 10.20.145.2
+"""
+NETWORK_CONFIG_TEST_DATA_V2 = """
+network:
+  version: 2
+  ethernets:
+    eth0:
+      match:
+        macaddress: "00:50:56:a1:8e:43"
+      set-name: "eth0"
+      addresses:
+      - 172.26.0.37/28
+      gateway4: 172.26.0.33
+      nameservers:
+        addresses:
+        - 10.20.145.1
+        - 10.20.145.2
+"""
+EXPECTED_NETWORK_LINK = network_model.Link(
+    id="eth0",
+    name="eth0",
+    type=network_model.LINK_TYPE_PHYSICAL,
+    enabled=True,
+    mac_address="00:50:56:a1:8e:43",
+    mtu=None,
+    bond=None,
+    vlan_link=None,
+    vlan_id=None)
+EXPECTED_NETWORK_NETWORK = network_model.Network(
+    link="eth0",
+    address_cidr="172.26.0.37/28",
+    dns_nameservers=["10.20.145.1", "10.20.145.2"],
+    routes=[network_model.Route(
+        network_cidr="0.0.0.0/0",
+        gateway="172.26.0.33")]
+)
+EXPECTED_NETWORK_NAME_SERVER = network_model.NameServerService(
+    addresses=['10.20.145.1', '10.20.145.2'],
+    search=None)
+EXPECTED_NETWORK_DETAILS_V1 = network_model.NetworkDetailsV2(
+    links=[EXPECTED_NETWORK_LINK],
+    networks=[EXPECTED_NETWORK_NETWORK],
+    services=[]
+)
+EXPECTED_NETWORK_DETAILS_V2 = network_model.NetworkDetailsV2(
+    links=[EXPECTED_NETWORK_LINK],
+    networks=[EXPECTED_NETWORK_NETWORK],
+    services=[EXPECTED_NETWORK_NAME_SERVER]
+)
+NETWORK_CONFIG_TEST_DATA_V2_GZIPB64 = """
+network: |
+    H4sIAHWT3mUCA22OSQrDMAxF9zmFyD6uPGRAtzGJaLqIC5ZJ6e3roYVSCgJJ/389dHKU2z0QmI7TzjFwEuo
+    A8oKlAxw+rXsby7L6bYssQtAj0phrIq9pYXK2rynhNAR/cE4UShPfVyyNNICejTKTQmXni1mqePWJH/7p6M
+    u01Sk44XjmZz+f/AArEpVBpd2o9B/NdC+Zoo9N7AAAAA==
+network.encoding: gzip+base64
+"""
 
 
 class FakeException(Exception):
@@ -90,32 +163,43 @@ class VMwareGuestInfoServiceTest(unittest.TestCase):
     @mock.patch(MODULE_PATH + "._get_guest_data")
     def _test_load_meta_data(self, mock_get_guestinfo, mock_parse,
                              mock_os_path_exists, parse_return=None,
-                             get_guest_data_result=None, exception=False,
+                             get_guest_data_results=None, exception=False,
                              expected_result=None, meta_data_return=False):
 
         mock_os_path_exists.return_value = True
         mock_parse.return_value = parse_return
 
         if not exception:
-            mock_get_guestinfo.return_value = get_guest_data_result
+            mock_get_guestinfo.side_effect = get_guest_data_results
             result = self._service.load()
             self.assertEqual(result, expected_result)
-            mock_get_guestinfo.assert_called_with('userdata')
-            mock_parse.assert_called_once_with(get_guest_data_result)
+            self.assertEqual(mock_get_guestinfo.call_args_list[0].args,
+                             ('metadata',))
+            self.assertEqual(mock_get_guestinfo.call_args_list[1].args,
+                             ('userdata',))
+            if get_guest_data_results and len(get_guest_data_results) > 1 \
+                    and get_guest_data_results[0]:
+                mock_parse.assert_called_once_with(get_guest_data_results[0])
             self.assertEqual(mock_get_guestinfo.call_count, 2)
             self.assertEqual(self._service._meta_data, meta_data_return)
-            self.assertEqual(self._service._user_data, get_guest_data_result)
+            self.assertEqual(self._service._user_data,
+                             get_guest_data_results[1])
         else:
             mock_get_guestinfo.side_effect = FakeException("Fake")
             self.assertRaises(FakeException, self._service.load)
 
     def test_load_no_meta_data(self):
-        self._test_load_meta_data(meta_data_return={})
+        self._test_load_meta_data(meta_data_return={},
+                                  expected_result=True,
+                                  get_guest_data_results=[None,
+                                                          "fake userdata"])
 
     def test_load_no_user_data(self):
         parse_return = {"fake": "metadata"}
         self._test_load_meta_data(parse_return=parse_return,
                                   expected_result=True,
+                                  get_guest_data_results=["fake metadata",
+                                                          None],
                                   meta_data_return=parse_return)
 
     def test_load_fail(self):
@@ -125,12 +209,15 @@ class VMwareGuestInfoServiceTest(unittest.TestCase):
     def test_load(self):
         parse_return = {"fake": "metadata"}
         self._test_load_meta_data(parse_return=parse_return,
-                                  get_guest_data_result="fake userdata",
+                                  get_guest_data_results=["fake metadata",
+                                                          "fake userdata"],
                                   expected_result=True,
                                   meta_data_return=parse_return)
 
     def test_load_no_dict_metadata(self):
         self._test_load_meta_data(parse_return="not_a_dict",
+                                  get_guest_data_results=["fake metadata",
+                                                          None],
                                   expected_result=None, meta_data_return={})
 
     @ddt.data((None, []),
@@ -181,6 +268,29 @@ class VMwareGuestInfoServiceTest(unittest.TestCase):
         mock_decode_data.assert_called_once_with(data_key_ret,
                                                  is_base64, is_gzip)
 
+    @ddt.data(({}, None),
+              (serialization.parse_json_yaml(NETWORK_CONFIG_TEST_DATA_V1),
+               EXPECTED_NETWORK_DETAILS_V1),
+              (serialization.parse_json_yaml(NETWORK_CONFIG_TEST_DATA_V2),
+               EXPECTED_NETWORK_DETAILS_V2))
+    @ddt.unpack
+    def test_get_network_details(self, network_data, expected_return_value):
+        self._service._meta_data = network_data
+
+        network_v2 = self._service.get_network_details_v2()
+        self.assertEqual(network_v2, expected_return_value)
+
+    @mock.patch(MODULE_PATH + "._get_guest_data")
+    @mock.patch('os.path.exists')
+    def test_get_network_details_v2_b64(self, mock_os_path_exists,
+                                        mock_get_guest_data):
+        mock_os_path_exists.return_value = True
+        mock_get_guest_data.return_value = NETWORK_CONFIG_TEST_DATA_V2_GZIPB64
+
+        self._service.load()
+        network_v2 = self._service.get_network_details_v2()
+        self.assertEqual(network_v2, EXPECTED_NETWORK_DETAILS_V2)
+
     @mock.patch(MODULE_PATH + "._get_guestinfo_value")
     def test_get_guest_data_fail(self, mock_get_guestinfo_value):
 
